# Features

Peplum provides a number of different features for searching and filtering
and discovering information about PEPs. Here's some assorted screenshots to
show them off:

## Browsing all the PEPs

Peplum, of course, lets you browse the whole list of PEPs.

```{.textual path="docs/screenshots/basic_app.py" title="Peplum" lines=50 columns=120}
```

## Filtering to a particular type of PEP

You can filter the list of PEPs down to one particular type (informational,
process, standards track):

```{.textual path="docs/screenshots/basic_app.py" title="Process type PEPs" lines=50 columns=120 press="t,p,r,o,c,e,s,s,enter"}
```

## Filtering to a particular status

You can filter the PEP list to those with a particular status (active, final, withdrawn, etc...):

```{.textual path="docs/screenshots/basic_app.py" title="Withdrawn PEPs" lines=50 columns=120 press="s,w,i,t,h,d,r,a,w,n,enter"}
```

## Filtering to a particular Python version

It's also possible to filter the PEPs down to those that relate to a particular Python version:

```{.textual path="docs/screenshots/basic_app.py" title="PEPs relating to Python 3.7" lines=50 columns=120 press="v,3,.,7,enter"}
```

## Filtering to a particular author

If you want to see all PEPs that had a particular author, you can do that too:

```{.textual path="docs/screenshots/basic_app.py" title="Looking at author with Steve in their name" lines=50 columns=120 press="u,s,t,e,v,e"}
```

```{.textual path="docs/screenshots/basic_app.py" title="All PEPs with a chosen author" lines=50 columns=120 press="u,s,t,e,v,e,enter"}
```

## Viewing the text of a PEP

You can view the source of the text of any given PEP:

```{.textual path="docs/screenshots/basic_app.py" title="Viewing the source text of a particular PEP" lines=50 columns=120 press="p,p,e,p,8,enter,f4"}
```

## Keeping notes for a particular PEP

Peplum also lets you keep some simple text notes for individual PEPs; so you
can leave comments and reminders for yourself.

```{.textual path="docs/screenshots/basic_app.py" title="Making a note about a PEP" lines=50 columns=120 press="p,p,e,p,2,0,,enter,f2,I, ,s,h,o,u,l,d, ,l,e,a,r,n, ,t,h,i,s, ,o,f,f, ,b,y, ,h,e,a,r,t,.,"}
```

[//]: # (features.md ends here)
